AccountDataSource class abstract

Abstract interface for retrieving account information.

Implementations of this interface provide access to account data from different sources.

Implementers

Constructors

AccountDataSource()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAccount({String? authToken}) → Future<Response<Account>>
Retrieves account information.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited