ProductDataSource class abstract

Abstract interface for retrieving product information.

Implementations of this interface provide access to product data from different sources.

Implementers

Constructors

ProductDataSource()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

barcodeLookup({required String barcode, String? authToken}) → Future<Response<Product>>
Looks up product information by barcode.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited